@@ -13,9 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from django.contrib.auth.models import AbstractUser
 from django.db import models
 
+from django.contrib.auth.models import AbstractUser
+
 
 class TestUser(AbstractUser):
     age = models.CharField(max_length=100, blank=True)
@@ -24,7 +25,7 @@ class TestUser(AbstractUser):
         self.first_name = first_name[0]
 
     class Meta:
-        app_label = 'testprofiles'
+        app_label = "testprofiles"
 
 
 class StandaloneUserModel(models.Model):
@@ -32,6 +33,7 @@ class StandaloneUserModel(models.Model):
     Does not inherit from Django's base abstract user and does not define a
     USERNAME_FIELD.
     """
+
     username = models.CharField(max_length=30, unique=True)
 
 
@@ -39,7 +41,7 @@ class RequiredFieldUser(models.Model):
     email = models.EmailField(unique=True)
     email_verified = models.BooleanField()
 
-    USERNAME_FIELD = 'email'
+    USERNAME_FIELD = "email"
 
     def __repr__(self):
         return self.email
