@@ -16,12 +16,14 @@
 
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.test import TestCase, override_settings
+from django.test import Client, TestCase, override_settings
+from django.urls import reverse
 
 from django.contrib.auth import get_user_model
 from django.contrib.auth.models import User as DjangoUserModel
 
 from djangosaml2.backends import Saml2Backend, get_saml_user_model, set_attribute
+from djangosaml2.utils import get_csp_handler
 from testprofiles.models import TestUser
 
 
@@ -294,7 +296,7 @@ class Saml2BackendTests(TestCase):
         self.assertFalse(created)
         self.assertIn(
             "ERROR:djangosaml2:Multiple users match, model: testprofiles.testuser, lookup: {'age': ''}",
-            logs.output,
+            logs.output[0],
         )
 
     def test_get_or_create_user_no_create(self):
@@ -314,7 +316,7 @@ class Saml2BackendTests(TestCase):
         self.assertFalse(created)
         self.assertIn(
             "ERROR:djangosaml2:The user does not exist, model: testprofiles.testuser, lookup: {'username': 'paul'}",
-            logs.output,
+            logs.output[0],
         )
 
     def test_get_or_create_user_create(self):
@@ -334,7 +336,7 @@ class Saml2BackendTests(TestCase):
         self.assertTrue(created)
         self.assertIn(
             f"DEBUG:djangosaml2:New user created: {user}",
-            logs.output,
+            logs.output[0],
         )
 
     def test_deprecations(self):
@@ -559,3 +561,36 @@ class CustomizedSaml2BackendTests(Saml2BackendTests):
 
         self.user.refresh_from_db()
         self.assertEqual(user.username, "john")
+
+
+class CSPHandlerTests(TestCase):
+    def test_get_csp_handler_none(self):
+        get_csp_handler.cache_clear()
+        with override_settings(SAML_CSP_HANDLER=None):
+            csp_handler = get_csp_handler()
+            self.assertIn(
+                csp_handler.__module__, ["csp.decorators", "djangosaml2.utils"]
+            )
+            self.assertIn(csp_handler.__name__, ["decorator", "empty_view_decorator"])
+
+    def test_get_csp_handler_empty(self):
+        get_csp_handler.cache_clear()
+        with override_settings(SAML_CSP_HANDLER=""):
+            csp_handler = get_csp_handler()
+            self.assertEqual(csp_handler.__name__, "empty_view_decorator")
+
+    def test_get_csp_handler_specified(self):
+        get_csp_handler.cache_clear()
+        with override_settings(SAML_CSP_HANDLER="testprofiles.utils.csp_handler"):
+            client = Client()
+            response = client.get(reverse("saml2_login"))
+            self.assertIn("Content-Security-Policy", response.headers)
+            self.assertEqual(
+                response.headers["Content-Security-Policy"], "testing CSP value"
+            )
+
+    def test_get_csp_handler_specified_missing(self):
+        get_csp_handler.cache_clear()
+        with override_settings(SAML_CSP_HANDLER="does.not.exist"):
+            with self.assertRaises(ImportError):
+                get_csp_handler()
